/*
   _===_ _           _                  ______ _     _             _ _ _
  |  ___| |         | |                 | ___ (_)   | |           (_) | |
  | |__ | | ___  ___| |_ _ __ ___ ______| |_/ /_  __| | ___  _   _ _| | | ___ _   _ _ __
  |  __|| |/ _ \/ __| __| '__/ _ \______| ___ \ |/ _` |/ _ \| | | | | | |/ _ \ | | | '__|
  | |___| |  __/ (__| |_| | | (_) |     | |_/ / | (_| | (_) | |_| | | | |  __/ |_| | |
  \____/|_|\___|\___|\__|_|  \___/      \____/|_|\__,_|\___/ \__,_|_|_|_|\___|\__,_|_|


  Bidouilleur Arduino - exemple d'écriture et de re-lecture d'un fichier log sur une carte SD.
  Électro-Bidouilleur, Mai 2018
  

Connexions SPI à l'adaptateur de carte SD:
MOSI -  broche 11
MISO -  broche 12
CLK  -  broche 13
CS   -  broche 4

*/

// Directives au compilateur
#include <SPI.h>
#include <SD.h>

// Définition des constantes
#define  bouton  10    // broche du bouton poussoir
File myFile;

// Définition des variables globales
int nombre_pressions = 1;    

// Fonction d'initialisation
void setup() 
{
  pinMode(bouton, INPUT_PULLUP);     // mise en entrée avec pullup de la broche du bouton
  // Ouverture du port série et attente de sa disponibilité
  Serial.begin(9600);
  while (!Serial);          // attente la disponibilité du port série
  Serial.print("Initialisation de la carte SD...");

  if (!SD.begin(4))     // Ouvrir le bus SPI en assignant la broche 4 au signal CS
  {
    Serial.println("echec d'initialisation!");
    return;
  }
  Serial.println("initialisation completee.");
}

// Fonction de boucle principale
void loop() 
{
  if (!digitalRead(bouton))     // Vérifier si le bouton est appuyé
  { // oui, enregistrer une entrée au fichier
    myFile = SD.open("log.txt", FILE_WRITE);    // Ouvrir le fichier en mode écriture
    if (myFile)  // Vérifier si le fichier est bien ouvert
    { // oui
      // Affichage du nombre de fois que le bouton a été pesé
      Serial.print("Nombre de fois: ");
      Serial.print(nombre_pressions);
      Serial.println(" fois.");
      Serial.println("");

      // Écriture sur du nombre de fois que le bouton a été pesé sur la carte SD
      myFile.print("Le bouton a ete pese ");
      myFile.print(nombre_pressions);
      myFile.println(" fois.");
      nombre_pressions++;   //incrémenter le compteur du nombre de fois
      // Fermeture du fichier:
      myFile.close();
      
      while(!digitalRead(bouton));    // Attendre que le bouton soit relâché avant de continuer
    } 
    else   // le fichier ne s'est pas bien ouvert
    {
      // Si le fichier ne s'est pas ouvert correctement, afficher un message d'erreur.
      Serial.println("erreur dans l'ouverture de log.txt");
    }

    // ré-ouveture du ficher pour vérifier son contenu
    myFile = SD.open("log.txt");
    if (myFile)   // Vérifier si le fichier est bien ouvert
    {
      Serial.println("contenu de log.txt:");

      // lire le contenu du fichier jusqu'à l'atteinte de la fin
      while (myFile.available())   //  boucle de lecture
      {
        Serial.write(myFile.read());      // lecture d'un caractère
      }
      Serial.println("fin de log.txt");  // fin du fichier atteinte.
      Serial.println("");
      // fermer le fichier:
      myFile.close();
    } 
    else    // le fichier ne s'est pas bien ouvert
    {
      // Si le fichier ne s'est pas ouvert correctement, afficher un message d'erreur.
      Serial.println("erreur dans l'ouverture de log.txt");
    }
  }
}


